@@ -3,10 +3,14 @@ from fief.schemas import (
     auth,
     client,
     generics,
+    permission,
     reset,
+    role,
     tenant,
     user,
     user_field,
+    user_permission,
+    user_role,
     well_known,
     workspace,
 )
@@ -17,9 +21,13 @@ __all__ = [
     "auth",
     "client",
     "generics",
+    "permission",
     "reset",
+    "role",
     "tenant",
     "user",
     "user_field",
+    "user_permission",
+    "user_role",
     "well_known",
 ]
